/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import java.io.File;

import com.beust.jcommander.JCommander;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class ArgsParser {

  private final Args args;

  public ArgsParser(String[] args) {
    this.args = new Args();
    new JCommander(this.args, args);
  }

  public Args parseAndValidate() throws ArgsException {
    templateShouldExist();

    postsShouldBeADirectory();

    return args;
  }

  private void templateShouldExist() throws ArgsException {
    File template = args.getTemplate();

    if (!template.exists()) {
      throw new ArgsException("Yikes! Could not find your template file: "
          + template.getPath());
    }
  }

  private void postsShouldBeADirectory() throws ArgsException {
    File posts = args.getPosts();

    if (!posts.exists()) {
      throw new ArgsException("Yikes! Could not find your posts directory: "
          + posts.getPath());
    }

    if (!posts.isDirectory()) {
      throw new ArgsException(
          "Yikes! Posts should be a directory and it is not: "
              + posts.getPath());
    }
  }

}