/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import java.io.File;
import java.util.List;

import com.google.inject.Inject;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class BlogEngineGuice implements BlogEngine {

  private final PostLoader postLoader;

  private final PostTemplateLoader postTemplateLoader;

  @Inject
  BlogEngineGuice(PostLoader postLoader, PostTemplateLoader postTemplateLoader) {
    this.postLoader = postLoader;
    this.postTemplateLoader = postTemplateLoader;
  }

  @Override
  public void make(Args args) throws BlogException {
    PostTemplate template = loadTemplate(args);
    List<Post> posts = loadPosts(args);
    File destination = args.getTarget();

    for (Post post : posts) {
      try {

        post.writeTo(template, destination);

      } catch (BlogIOException e) {

        System.err.println("Could not read/write a file.");
        e.printStackTrace();

      }
    }
  }

  private PostTemplate loadTemplate(Args args) throws BlogException {
    File templateFile = args.getTemplate();
    PostTemplate template = postTemplateLoader.loadFromFile(templateFile);
    return template;
  }

  private List<Post> loadPosts(Args args) {
    File postsDir = args.getPosts();
    List<Post> posts = postLoader.loadAll(postsDir);
    return posts;
  }

}