/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import static com.google.common.collect.Lists.newArrayList;

import java.io.File;
import java.util.List;

import com.google.common.base.Preconditions;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
class PostList {

  private final File directory;

  private final List<File> posts = newArrayList();

  public PostList(File directory) {
    this.directory = directory;
  }

  public List<File> build() {
    new Recursion(directory).go();
    return posts;
  }

  public class Recursion {

    private final File directory;

    private Recursion(File directory) {
      Preconditions.checkArgument(directory.isDirectory());
      this.directory = directory;
    }

    public void go() {
      List<File> directories = newArrayList();

      File[] contents = directory.listFiles();
      for (File file : contents) {
        String filename = file.getName();

        if (file.isDirectory()) {

          directories.add(file);

        } else if (isPost(filename)) {

          posts.add(file);

        }
      }

      for (File subdir : directories) {
        new Recursion(subdir).go();
      }
    }

    private boolean isPost(String filename) {
      return filename.matches("^[0-9]+.*\\.txt$");
    }

  }

}