/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import static com.google.common.collect.Lists.newArrayListWithCapacity;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import br.com.objectos.blog.syntax.Document;
import br.com.objectos.blog.syntax.DocumentBuilder;
import br.com.objectos.blog.syntax.Syntax;
import br.com.objectos.blog.syntax.SyntaxAnalyzer;
import br.com.objectos.blog.syntax.SyntaxException;

import com.google.common.base.Preconditions;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class PostLoaderGuice implements PostLoader {

  @Override
  public Post load(File file) throws IOException {
    return new PostBuilder(file).get();
  }

  @Override
  public List<Post> loadAll(File dir) {
    Preconditions.checkArgument(dir.isDirectory());

    List<File> postFiles = new PostList(dir).build();
    List<Post> posts = newArrayListWithCapacity(postFiles.size());

    for (File postFile : postFiles) {
      try {

        Post post = load(postFile);
        posts.add(post);

      } catch (IOException e) {

        System.err.println("Sorry, could not load post file: "
            + postFile.getPath());

      }
    }

    return posts;
  }

  private class PostBuilder implements Post.Builder {

    private final File file;

    public PostBuilder(File file) {
      this.file = file;
    }

    @Override
    public Post get() {
      return new PostImpl(this);
    }

    @Override
    public String getId() {
      String name = file.getName();
      Pattern pattern = Pattern.compile("^([0-9]+)");
      Matcher matcher = pattern.matcher(name);

      Integer id = Integer.valueOf(0);

      if (matcher.find()) {
        String group = matcher.group();
        id = Integer.valueOf(group);
      }

      return String.format("%06d", id.intValue());
    }

    @Override
    public Document getDocument() throws SyntaxException {
      List<Syntax> syntaxes = new SyntaxAnalyzer(file).analyze();
      return new DocumentBuilder(syntaxes).get();
    }

  }

}