/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public enum PostTag {

  POST_ID,
  POST_PATH,
  TITLE,
  AUTHOR,
  DATE,
  CONTENTS;

  private final String regex;
  private final String pattern;
  private final String xpath;

  private PostTag() {
    String lowerName = name().toLowerCase();
    regex = String.format("\\{\\{%s\\}\\}", lowerName);
    pattern = String.format("{{%s}}", lowerName);
    this.xpath = String.format("*:containsOwn(%s)", regex);
  }

  public void replace(Element theElement, String newText) {
    if (theElement != null) {
      String html = theElement.html();
      String newHtml = html.replaceAll(regex, newText);
      theElement.html(newHtml);
    }
  }

  public Elements selectFrom(Document doc) {
    Elements elements = new Elements();

    Elements fromXpath = doc.select(xpath);
    elements.addAll(fromXpath);

    Elements scripts = doc.getElementsByTag("script");
    for (Element script : scripts) {
      String html = script.html();

      if (html.contains(pattern)) {
        elements.add(script);
      }
    }

    return elements;
  }

}