/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class BlockquoteStart implements Syntax, HtmlElement {

  private final String text;

  private final StringBuilder buffer;

  private HtmlElement last;

  public BlockquoteStart(String text) {
    this.text = text.trim();
    this.buffer = new StringBuilder(text);
  }

  public static SyntaxFactory factory() {
    return new SyntaxFactory() {
      @Override
      public Syntax get(String text) {
        return new BlockquoteStart(text);
      }
    };
  }

  @Override
  public boolean merge(HtmlElement next) {
    boolean merged = true;

    HtmlElement current = next;

    if (last != null) {
      boolean localMerge = last.merge(current);

      if (!localMerge) {
        buffer.append(last.toString());
        last = current;
      }
    } else {
      last = current;
    }

    if (next instanceof BlockquoteEnd) {
      buffer.append(last.toString());
      BlockquoteEnd end = (BlockquoteEnd) next;
      buffer.append(end.toString());
      merged = false;
    }

    return merged;
  }

  @Override
  public boolean isPrintable() {
    return true;
  }

  @Override
  public boolean matches() {
    return text.equals("<blockquote>");
  }

  @Override
  public String toString() {
    return buffer.toString();
  }

}