/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import static com.google.common.collect.Lists.newArrayList;

import java.util.List;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class DocumentBuilder implements Document.Builder {

  private static final String SEPARATOR = System.getProperty("line.separator");

  private final List<Meta> meta = newArrayList();

  private final List<HtmlElement> elements = newArrayList();

  public DocumentBuilder(List<Syntax> syntaxList) {

    for (Syntax syntax : syntaxList) {

      if (syntax instanceof Meta) {
        meta.add((Meta) syntax);

      } else if (syntax instanceof HtmlElement) {
        elements.add((HtmlElement) syntax);

      }

    }

  }

  @Override
  public Document get() {
    return new DocumentImpl(this);
  }

  @Override
  public List<Meta> getMeta() {
    return meta;
  }

  @Override
  public String getContents() {
    StringBuilder html = new StringBuilder();

    List<HtmlElement> mergedElements = merge();
    for (HtmlElement el : mergedElements) {
      if (el.isPrintable()) {
        html.append(el);
        html.append(SEPARATOR);
      }
    }

    return html.toString();
  }

  private List<HtmlElement> merge() {
    List<HtmlElement> mergedElements = newArrayList();

    HtmlElement last = null;

    for (HtmlElement current : elements) {
      boolean merged = false;

      if (last != null) {
        merged = last.merge(current);
      }

      if (!merged) {
        mergedElements.add(current);
        last = current;
      }
    }

    return mergedElements;
  }

}