/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import static com.google.common.collect.Maps.newHashMap;

import java.util.List;
import java.util.Map;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
class DocumentImpl implements Document {

  private final Map<MetaType<?>, Meta> metaMap = newHashMap();

  private final String content;

  DocumentImpl(Builder builder) {
    List<Meta> meta = builder.getMeta();

    for (Meta _meta : meta) {
      MetaType<?> key = _meta.getKey();
      metaMap.put(key, _meta);
    }

    this.content = builder.getContents();
  }

  @SuppressWarnings("unchecked")
  @Override
  public <T> T getMetaValue(MetaType<T> key) {
    T value = null;

    if (metaMap.containsKey(key)) {
      Meta meta = metaMap.get(key);

      // should be safe, we control the metaMap
      value = (T) meta.getValue();
    }

    return value;
  }

  @Override
  public String getContents() {
    return content;
  }

}