/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class Heading implements Syntax, HtmlElement {

  private static final String regex = "^[\\-]{3,}(\\++)(.*)$";

  private final boolean matches;

  private final String text;

  public Heading(String text) {
    this.matches = text.matches(regex);
    this.text = parse(text);
  }

  public static SyntaxFactory factory() {
    return new SyntaxFactory() {
      @Override
      public Syntax get(String text) {
        return new Heading(text);
      }
    };
  }

  @Override
  public boolean matches() {
    return matches;
  }

  @Override
  public boolean isPrintable() {
    return true;
  }

  @Override
  public boolean merge(HtmlElement next) {
    return false;
  }

  @Override
  public String toString() {
    return text;
  }

  private String parse(String text) {
    String result = text;

    if (matches) {
      result = parse0(text);
    }

    return new TextDecorator(result).decorate();
  }

  private String parse0(String text) {
    Pattern pattern = Pattern.compile(regex);
    Matcher m = pattern.matcher(text);
    m.matches();

    String plus = m.group(1);
    int level = plus.length();

    String heading = m.group(2);

    return String.format("<h%d>%s</h%d>", level, heading.trim(), level);
  }

}