/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class Meta implements Syntax {

  private static final String regex = "^%META:([A-Z]*)\\{(.*)\\}%$";

  private final boolean matches;

  private final KeyValue keyValue;

  private final String text;

  public Meta(String text) {
    this.matches = text.matches(regex);
    this.keyValue = new KeyValue(text);
    this.text = keyValue.toString();
  }

  public static SyntaxFactory factory() {
    return new SyntaxFactory() {
      @Override
      public Syntax get(String text) {
        return new Meta(text);
      }
    };
  }

  public MetaType<?> getKey() {
    return keyValue.getKey();
  }

  public Object getValue() {
    return keyValue.getValue();
  }

  @Override
  public boolean matches() {
    return matches;
  }

  @Override
  public String toString() {
    return text;
  }

  private class KeyValue {

    private MetaType<?> key;

    private final Object value;

    public KeyValue(String text) {
      if (matches) {
        Pattern pattern = Pattern.compile(regex);

        Matcher m = pattern.matcher(text);
        m.matches();

        String keyName = m.group(1);
        String valueName = m.group(2);

        key = MetaTypes.valueOf(keyName);
        value = key.toValue(valueName);
      } else {
        key = null;
        value = null;
      }
    }

    public MetaType<?> getKey() {
      return key;
    }

    public Object getValue() {
      return value;
    }

    @Override
    public String toString() {
      return String.format("%s=%s", key, value);
    }

  }

}