/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import java.util.Collection;
import java.util.Set;

import org.joda.time.DateTime;

import com.google.common.collect.ImmutableSet;
import com.google.common.collect.ImmutableSet.Builder;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class MetaTypes {

  public static final MetaType<String> TITLE = new MetaStringType("TITLE");

  public static final MetaType<String> AUTHOR = new MetaStringType("AUTHOR");

  public static final MetaType<DateTime> DATE = new MetaDateTimeType("DATE");

  private static final Set<MetaType<?>> values;

  static {
    Builder<MetaType<?>> builder = ImmutableSet.builder();

    builder.add(TITLE);
    builder.add(AUTHOR);
    builder.add(DATE);

    values = builder.build();
  }

  private MetaTypes() {
  }

  public static MetaType<?> valueOf(String keyName) {
    MetaType<?> value = null;

    for (MetaType<?> type : values) {
      if (type.matches(keyName)) {
        value = type;
        break;
      }
    }

    if (value != null) {
      return value;
    } else {
      throw new InvalidMetaKeyException(keyName);
    }
  }

  public static Collection<MetaType<?>> values() {
    return values;
  }

}