/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
public class Paragraph implements Syntax, HtmlElement {

  private static final String SEPARATOR = System.getProperty("line.separator");

  private final boolean matches;

  private final String text;
  private final StringBuilder buffer;

  public Paragraph(String text) {
    this.matches = !"".equals(text);
    this.text = parse(text);
    this.buffer = new StringBuilder();
    this.buffer.append(this.text);
  }

  public static SyntaxFactory factory() {
    return new SyntaxFactory() {
      @Override
      public Syntax get(String text) {
        return new Paragraph(text);
      }
    };
  }

  @Override
  public boolean matches() {
    return matches;
  }

  @Override
  public boolean isPrintable() {
    return true;
  }

  @Override
  public boolean merge(HtmlElement next) {
    boolean merged = false;

    if (next instanceof Paragraph) {
      Paragraph p = (Paragraph) next;
      buffer.append(p.text);
      merged = true;
    } else if (next instanceof BlockquoteEnd) {
      merged = true;
    }

    return merged;
  }

  @Override
  public String toString() {
    return String.format("<p>%s%s</p>", SEPARATOR, buffer);
  }

  private String parse(String text) {
    String result = new TextDecorator(text).decorate();
    return result + SEPARATOR;
  }

}