/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
class TextDecorator {

  private final String text;

  public TextDecorator(String text) {
    this.text = text;
  }

  public String decorate() {
    String result = text;

    result = bold(result);
    result = boldItalic(result);
    result = boldFixed(result);
    result = italic(result);
    result = fixed(result);

    return result;
  }

  private String bold(String text) {
    return new Parser("\\*(.*?)\\*", "<strong>%s</strong>").parse(text);
  }

  private String boldFixed(String text) {
    return new Parser("==(.*?)==", "<code><b>%s</b></code>").parse(text);
  }

  private String boldItalic(String text) {
    return new Parser("__(.*?)__", "<strong><em>%s</em></strong>").parse(text);
  }

  private String fixed(String text) {
    return new Parser("=(.*?)=", "<code>%s</code>").parse(text);
  }

  private String italic(String text) {
    return new Parser("_(.*?)_", "<em>%s</em>").parse(text);
  }

}