/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core;

import java.util.List;

import br.com.objectos.comuns.base.cache.CacheBuilder;

import com.google.common.base.Optional;
import com.google.common.cache.CacheLoader;
import com.google.common.cache.CacheLoader.InvalidCacheLoadException;
import com.google.common.cache.LoadingCache;
import com.google.inject.Inject;
import com.google.inject.Singleton;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
@Singleton
class WebCacheGuice implements WebCache {

  private final LoadingCache<Boolean, List<Web>> allCache;

  private final LoadingCache<String, Web> codeCache;

  private final FindWeb findWeb;

  @Inject
  public WebCacheGuice(CacheBuilder cacheBuilder, FindWeb findWeb) {
    this.allCache = cacheBuilder
        .small()
        .build(new AllLoader());
    this.codeCache = cacheBuilder
        .small()
        .build(new CodeLoader());
    this.findWeb = findWeb;
  }

  @Override
  public List<Web> all() {
    return allCache.getUnchecked(Boolean.TRUE);
  }

  @Override
  public Optional<Web> byCode(String code) {
    try {
      Web web = codeCache.getUnchecked(code);
      return Optional.of(web);
    } catch (InvalidCacheLoadException e) {
      return Optional.absent();
    }
  }

  private class AllLoader extends CacheLoader<Boolean, List<Web>> {
    @Override
    public List<Web> load(Boolean key) throws Exception {
      return findWeb.all();
    }
  }

  private class CodeLoader extends CacheLoader<String, Web> {
    @Override
    public Web load(String code) throws Exception {
      return findWeb.byCode(code);
    }
  }

}