/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.joda.time.DateTime;

import br.com.objectos.comuns.relational.jdbc.GeneratedKeyCallback;
import br.com.objectos.comuns.relational.jdbc.Insert;
import br.com.objectos.wiki.core.auth.User;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class WebJdbc implements Web {

  private int id;
  private final String code;
  private final String description;
  private final User user;
  private final DateTime creationTime;
  private final DateTime lastUpdate;

  public WebJdbc(Builder builder) {
    code = builder.getCode();
    description = builder.getDescription();
    user = builder.getUser();
    creationTime = builder.getCreationTime();
    lastUpdate = builder.getLastUpdate();
  }

  @Override
  public Insert getInsert() {
    return Insert.into("OBJ_WIKI.WEB")

        .value("CODE", code)
        .value("DESCRIPTION", description)
        .value("USER_ID", user.getId())
        .value("CREATION_TIME", creationTime)
        .value("LAST_UPDATE", lastUpdate)

        .onGeneratedKey(new GeneratedKeyCallback() {
          @Override
          public void set(ResultSet rs) throws SQLException {
            id = rs.next() ? rs.getInt(1) : 0;
          }
        });
  }

  @Override
  public WebKey getKey() {
    return new WebKey(this);
  }

  @Override
  public int getId() {
    return id;
  }

  void setId(int id) {
    this.id = id;
  }

  @Override
  public String getCode() {
    return code;
  }

  @Override
  public String getDescription() {
    return description;
  }

  @Override
  public User getUser() {
    return user;
  }

  @Override
  public DateTime getCreationTime() {
    return creationTime;
  }

  @Override
  public DateTime getLastUpdate() {
    return lastUpdate;
  }

}