/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.attach;

import java.util.List;

import br.com.objectos.comuns.base.cache.CacheBuilder;
import br.com.objectos.wiki.core.page.WikiPageKey;

import com.google.common.cache.CacheLoader;
import com.google.common.cache.LoadingCache;
import com.google.inject.Inject;
import com.google.inject.Singleton;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
@Singleton
class AttachmentCacheGuice implements AttachmentCache {

  private final LoadingCache<WikiPageKey, List<Attachment>> attachmentKeyCache;

  private final FindAttachment findAttachment;

  @Inject
  public AttachmentCacheGuice(CacheBuilder cacheBuilder, FindAttachment findAttachment) {
    this.attachmentKeyCache = cacheBuilder
        .medium()
        .build(new AttachmentKeyLoader());
    this.findAttachment = findAttachment;
  }

  @Override
  public List<Attachment> byPageKey(WikiPageKey pageKey) {
    return attachmentKeyCache.getUnchecked(pageKey);
  }

  private class AttachmentKeyLoader extends CacheLoader<WikiPageKey, List<Attachment>> {
    @Override
    public List<Attachment> load(WikiPageKey pageKey) throws Exception {
      return findAttachment.byPageKey(pageKey);
    }
  }

}