/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.attach;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.UUID;

import org.joda.time.DateTime;

import br.com.objectos.comuns.relational.jdbc.GeneratedKeyCallback;
import br.com.objectos.comuns.relational.jdbc.Insert;
import br.com.objectos.wiki.core.auth.User;
import br.com.objectos.wiki.core.page.WikiPage;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class AttachmentJdbc implements Attachment {

  private int id;
  private final UUID uuid;
  private final WikiPage page;
  private final String mime;
  private final String name;
  private final String description;
  private final long size;
  private final User user;
  private final DateTime creationTime;
  private final DateTime lastUpdate;

  public AttachmentJdbc(Builder builder) {
    uuid = builder.getUuid();
    page = builder.getPage();
    mime = builder.getMime();
    name = builder.getName();
    description = builder.getDescription();
    size = builder.getSize();
    user = builder.getUser();
    creationTime = builder.getCreationTime();
    lastUpdate = builder.getLastUpdate();
  }

  @Override
  public Insert getInsert() {
    return Insert.into("OBJ_WIKI.ATTACHMENT")

        .value("UUID", uuid.toString())
        .value("PAGE_ID", page.getId())
        .value("MIME", mime)
        .value("NAME", name)
        .value("DESCRIPTION", description)
        .value("SIZE", size)
        .value("USER_ID", user.getId())
        .value("CREATION_TIME", creationTime)
        .value("LAST_UPDATE", lastUpdate)

        .onGeneratedKey(new GeneratedKeyCallback() {
          @Override
          public void set(ResultSet rs) throws SQLException {
            id = rs.next() ? rs.getInt(1) : 0;
          }
        });
  }

  @Override
  public int getId() {
    return id;
  }

  void setId(int id) {
    this.id = id;
  }

  @Override
  public UUID getUuid() {
    return uuid;
  }

  @Override
  public WikiPage getPage() {
    return page;
  }

  @Override
  public String getMime() {
    return mime;
  }

  @Override
  public String getName() {
    return name;
  }

  @Override
  public String getDescription() {
    return description;
  }

  @Override
  public long getSize() {
    return size;
  }

  @Override
  public User getUser() {
    return user;
  }

  @Override
  public DateTime getCreationTime() {
    return creationTime;
  }

  @Override
  public DateTime getLastUpdate() {
    return lastUpdate;
  }

}