/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.attach;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.UUID;

import org.joda.time.DateTime;

import br.com.objectos.comuns.relational.jdbc.ResultSetWrapper;
import br.com.objectos.comuns.relational.search.ResultSetLoader;
import br.com.objectos.wiki.core.auth.User;
import br.com.objectos.wiki.core.auth.UserLoader;
import br.com.objectos.wiki.core.page.WikiPage;
import br.com.objectos.wiki.core.page.WikiPageLoader;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class AttachmentLoader implements ResultSetLoader<Attachment> {

  @Override
  public Attachment load(ResultSet resultSet) throws SQLException {
    ResultSetWrapper rs = new ResultSetWrapper("ATTACHMENT", resultSet);
    return new Loader(rs).build();
  }

  private class Loader implements Attachment.Builder {

    private final ResultSetWrapper rs;

    public Loader(ResultSetWrapper rs) {
      this.rs = rs;
    }

    @Override
    public Attachment build() {
      AttachmentJdbc impl = new AttachmentJdbc(this);
      impl.setId(rs.getInt("ID"));
      return impl;
    }

    @Override
    public UUID getUuid() {
      String uuid = rs.getString("UUID");
      return UUID.fromString(uuid);
    }

    @Override
    public WikiPage getPage() {
      ResultSet resultSet = rs.getResultSet();
      return new WikiPageLoader().load(resultSet);
    }

    @Override
    public String getMime() {
      return rs.getString("MIME");
    }

    @Override
    public String getName() {
      return rs.getString("NAME");
    }

    @Override
    public String getDescription() {
      return rs.getString("DESCRIPTION");
    }

    @Override
    public long getSize() {
      return rs.getLong("SIZE");
    }

    @Override
    public User getUser() {
      ResultSet resultSet = rs.getResultSet();
      return new UserLoader().load(resultSet);
    }

    @Override
    public DateTime getCreationTime() {
      return rs.getDateTime("CREATION_TIME");
    }

    @Override
    public DateTime getLastUpdate() {
      return rs.getDateTime("LAST_UPDATE");
    }

  }

}