/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.attach;

import java.util.List;

import br.com.objectos.comuns.relational.jdbc.NativeSql;
import br.com.objectos.wiki.core.page.WikiPageKey;

import com.google.inject.Inject;
import com.google.inject.Provider;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
class FindAttachmentGuice implements FindAttachment {

  private final Provider<NativeSql> sqlProvider;

  @Inject
  public FindAttachmentGuice(Provider<NativeSql> sqlProvider) {
    this.sqlProvider = sqlProvider;
  }

  @Override
  public List<Attachment> byPageKey(WikiPageKey pageKey) {
    return newSelect()

        .add("where ATTACHMENT.PAGE_ID = ?").param(pageKey.getId())

        .list();
  }

  private NativeSql newSelect() {
    return sqlProvider.get()

        .add("select *")
        .add("from OBJ_WIKI.ATTACHMENT")

        .add("join OBJ_WIKI.USER")
        .add("on ATTACHMENT.USER_ID = USER.ID")

        .add("join OBJ_WIKI.WIKI_PAGE")
        .add("on ATTACHMENT.PAGE_ID = WIKI_PAGE.ID")

        .add("join OBJ_WIKI.WEB")
        .add("on WIKI_PAGE.WEB_ID = WEB.ID")

        .andLoadWith(new AttachmentLoader());
  }

}