/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.auth;

import br.com.objectos.comuns.base.cache.CacheBuilder;

import com.google.common.cache.CacheLoader;
import com.google.common.cache.LoadingCache;
import com.google.inject.Inject;
import com.google.inject.Singleton;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
@Singleton
class UserCacheGuice implements UserCache {

  private final LoadingCache<String, User> userCache;
  private final FindUser findUser;

  @Inject
  public UserCacheGuice(CacheBuilder cacheBuilder, FindUser findUser) {
    this.userCache = cacheBuilder.small().build(new UserLoader());
    this.findUser = findUser;
  }

  @Override
  public User byLogin(String login) {
    return userCache.getUnchecked(login);
  }

  private class UserLoader extends CacheLoader<String, User> {
    @Override
    public User load(String key) throws Exception {
      return findUser.byLogin(key);
    }
  }

}