/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.auth;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.joda.time.DateTime;

import br.com.objectos.comuns.relational.jdbc.GeneratedKeyCallback;
import br.com.objectos.comuns.relational.jdbc.Insert;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class UserJdbc implements User {

  private int id;
  private final String login;
  private final String password;
  private final DateTime creationTime;
  private final DateTime lastUpdate;

  public UserJdbc(Builder builder) {
    login = builder.getLogin();
    password = builder.getPassword();
    creationTime = builder.getCreationTime();
    lastUpdate = builder.getLastUpdate();
  }

  @Override
  public Insert getInsert() {
    return Insert.into("OBJ_WIKI.USER")

        .value("LOGIN", login)
        .value("PASSWORD", password)
        .value("CREATION_TIME", creationTime)
        .value("LAST_UPDATE", lastUpdate)

        .onGeneratedKey(new GeneratedKeyCallback() {
          @Override
          public void set(ResultSet rs) throws SQLException {
            id = rs.next() ? rs.getInt(1) : 0;
          }
        });
  }

  @Override
  public UserKey getKey() {
    return new UserKey(this);
  }

  @Override
  public int getId() {
    return id;
  }

  void setId(int id) {
    this.id = id;
  }

  @Override
  public String getLogin() {
    return login;
  }

  @Override
  public String getPassword() {
    return password;
  }

  @Override
  public DateTime getCreationTime() {
    return creationTime;
  }

  @Override
  public DateTime getLastUpdate() {
    return lastUpdate;
  }

}