/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.auth;

import java.sql.ResultSet;

import org.joda.time.DateTime;

import br.com.objectos.comuns.relational.jdbc.ResultSetWrapper;
import br.com.objectos.comuns.relational.search.ResultSetLoader;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class UserLoader implements ResultSetLoader<User> {

  @Override
  public User load(ResultSet resultSet) {
    ResultSetWrapper rs = new ResultSetWrapper("USER", resultSet);
    return new Loader(rs).build();
  }

  private class Loader implements User.Builder {

    private final ResultSetWrapper rs;

    public Loader(ResultSetWrapper rs) {
      this.rs = rs;
    }

    @Override
    public User build() {
      UserJdbc impl = new UserJdbc(this);
      impl.setId(rs.getInt("ID"));
      return impl;
    }

    @Override
    public String getLogin() {
      return rs.getString("LOGIN");
    }

    @Override
    public String getPassword() {
      return rs.getString("PASSWORD");
    }

    @Override
    public DateTime getCreationTime() {
      return rs.getDateTime("CREATION_TIME");
    }

    @Override
    public DateTime getLastUpdate() {
      return rs.getDateTime("LAST_UPDATE");
    }

  }

}