/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.mail;

import java.util.List;

import br.com.objectos.comuns.base.cache.CacheBuilder;
import br.com.objectos.wiki.core.auth.UserKey;

import com.google.common.cache.CacheLoader;
import com.google.common.cache.LoadingCache;
import com.google.inject.Inject;
import com.google.inject.Singleton;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
@Singleton
class EmailCacheGuice implements EmailCache {

  private final LoadingCache<UserKey, List<Email>> userKeyCache;

  private final FindEmail findEmail;

  @Inject
  public EmailCacheGuice(CacheBuilder cacheBuilder, FindEmail findEmail) {
    this.userKeyCache = cacheBuilder
        .small()
        .build(new UserKeyLoader());
    this.findEmail = findEmail;
  }

  @Override
  public List<Email> byUserKey(UserKey userKey) {
    return userKeyCache.getUnchecked(userKey);
  }

  private class UserKeyLoader extends CacheLoader<UserKey, List<Email>> {
    @Override
    public List<Email> load(UserKey userKey) throws Exception {
      return findEmail.byUserKey(userKey);
    }
  }

}