/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.mail;

import java.sql.ResultSet;
import java.sql.SQLException;

import br.com.objectos.comuns.relational.jdbc.ResultSetWrapper;
import br.com.objectos.comuns.relational.search.ResultSetLoader;
import br.com.objectos.wiki.core.auth.User;
import br.com.objectos.wiki.core.auth.UserLoader;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
class EmailLoader implements ResultSetLoader<Email> {

  @Override
  public Email load(ResultSet resultSet) throws SQLException {
    ResultSetWrapper rs = new ResultSetWrapper("EMAIL", resultSet);
    return new Loader(rs).build();
  }

  private class Loader implements Email.Builder {

    private final ResultSetWrapper rs;

    public Loader(ResultSetWrapper rs) {
      this.rs = rs;
    }

    @Override
    public Email build() {
      EmailJdbc impl = new EmailJdbc(this);
      impl.setId(rs.getInt("ID"));
      return impl;
    }

    @Override
    public User getUser() {
      ResultSet resultSet = rs.getResultSet();
      return new UserLoader().load(resultSet);
    }

    @Override
    public String getAddress() {
      return rs.getString("ADDRESS");
    }

  }

}