/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.page;

import java.sql.ResultSet;
import java.sql.SQLException;

import br.com.objectos.comuns.relational.jdbc.GeneratedKeyCallback;
import br.com.objectos.comuns.relational.jdbc.Insert;
import br.com.objectos.wiki.core.Web;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class WikiPageJdbc implements WikiPage {

  private int id;
  private final Web web;
  private final String wikiWord;

  public WikiPageJdbc(Builder builder) {
    web = builder.getWeb();
    wikiWord = builder.getWikiWord();
  }

  @Override
  public Insert getInsert() {
    return Insert.into("OBJ_WIKI.WIKI_PAGE")

        .value("WEB_ID", web.getId())
        .value("WIKI_WORD", wikiWord)

        .onGeneratedKey(new GeneratedKeyCallback() {
          @Override
          public void set(ResultSet rs) throws SQLException {
            id = rs.next() ? rs.getInt(1) : 0;
          }
        });
  }

  @Override
  public WikiPageKey getKey() {
    return new WikiPageKey(this);
  }

  @Override
  public int getId() {
    return id;
  }

  void setId(int id) {
    this.id = id;
  }

  @Override
  public Web getWeb() {
    return web;
  }

  @Override
  public String getWikiWord() {
    return wikiWord;
  }

}