/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.page;

import br.com.objectos.wiki.core.Web;
import br.com.objectos.wiki.core.WebKey;

import com.google.common.base.Objects;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class WikiPageKey {

  private final WebKey webKey;

  private final int id;

  public WikiPageKey(WikiPage page) {
    Web web = page.getWeb();
    this.webKey = web.getKey();
    this.id = page.getId();
  }

  public WebKey getWebKey() {
    return webKey;
  }

  public int getId() {
    return id;
  }

  @Override
  public final int hashCode() {
    return Objects.hashCode(webKey, id);
  }

  @Override
  public final boolean equals(final Object obj) {
    if (obj == this) {
      return true;
    }
    if (obj == null) {
      return false;
    }
    if (obj instanceof WikiPageKey) {
      final WikiPageKey that = (WikiPageKey) obj;
      return Objects.equal(this.webKey, that.webKey)
          && Objects.equal(this.id, that.id);
    } else {
      return false;
    }
  }

}