/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.page;

import java.sql.ResultSet;

import br.com.objectos.comuns.relational.jdbc.ResultSetWrapper;
import br.com.objectos.comuns.relational.search.ResultSetLoader;
import br.com.objectos.wiki.core.Web;
import br.com.objectos.wiki.core.WebLoader;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class WikiPageLoader implements ResultSetLoader<WikiPage> {

  @Override
  public WikiPage load(ResultSet resultSet) {
    ResultSetWrapper rs = new ResultSetWrapper("WIKI_PAGE", resultSet);
    return new Loader(rs).build();
  }

  private class Loader implements WikiPage.Builder {

    private final ResultSetWrapper rs;

    public Loader(ResultSetWrapper rs) {
      this.rs = rs;
    }

    @Override
    public WikiPage build() {
      WikiPageJdbc impl = new WikiPageJdbc(this);
      impl.setId(rs.getInt("ID"));
      return impl;
    }

    @Override
    public Web getWeb() {
      ResultSet resultSet = rs.getResultSet();
      return new WebLoader().load(resultSet);
    }

    @Override
    public String getWikiWord() {
      return rs.getString("WIKI_WORD");
    }

  }

}