/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.page;

import java.util.List;

import br.com.objectos.comuns.base.cache.CacheBuilder;

import com.google.common.cache.CacheLoader;
import com.google.common.cache.LoadingCache;
import com.google.inject.Inject;
import com.google.inject.Singleton;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
@Singleton
class WikiRevisionCacheCache implements WikiRevisionCache {

  private final LoadingCache<WikiPageKey, List<WikiRevision>> wikiRevisionKeyCache;
  private final FindWikiRevision findWikiRevision;

  @Inject
  public WikiRevisionCacheCache(CacheBuilder cacheBuilder,
                                FindWikiRevision findWikiRevision) {
    this.wikiRevisionKeyCache = cacheBuilder
        .medium()
        .build(new WikiRevisionLoader());
    this.findWikiRevision = findWikiRevision;
  }

  @Override
  public List<WikiRevision> byPageKey(WikiPageKey pageKey) {
    return wikiRevisionKeyCache.getUnchecked(pageKey);
  }

  private class WikiRevisionLoader extends CacheLoader<WikiPageKey, List<WikiRevision>> {

    @Override
    public List<WikiRevision> load(WikiPageKey pageKey) throws Exception {
      return findWikiRevision.byPageKey(pageKey);
    }
  }

}