/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.page;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.joda.time.DateTime;

import br.com.objectos.comuns.relational.jdbc.GeneratedKeyCallback;
import br.com.objectos.comuns.relational.jdbc.Insert;
import br.com.objectos.wiki.core.auth.User;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class WikiRevisionJdbc implements WikiRevision {

  private int id;
  private final WikiPage page;
  private final String contents;
  private final User user;
  private final DateTime dateTime;

  public WikiRevisionJdbc(Builder builder) {
    page = builder.getPage();
    contents = builder.getContents();
    user = builder.getUser();
    dateTime = builder.getDateTime();
  }

  @Override
  public Insert getInsert() {
    return Insert.into("OBJ_WIKI.WIKI_REVISION")

        .value("PAGE_ID", page.getId())
        .value("CONTENTS", contents)
        .value("USER_ID", user.getId())
        .value("DATE_TIME", dateTime)

        .onGeneratedKey(new GeneratedKeyCallback() {
          @Override
          public void set(ResultSet rs) throws SQLException {
            id = rs.next() ? rs.getInt(1) : 0;
          }
        });
  }

  @Override
  public WikiPageKey getKey() {
    return new WikiPageKey(page);
  }

  @Override
  public int getId() {
    return id;
  }

  void setId(int id) {
    this.id = id;
  }

  @Override
  public WikiPage getPage() {
    return page;
  }

  @Override
  public String getContents() {
    return contents;
  }

  @Override
  public User getUser() {
    return user;
  }

  @Override
  public DateTime getDateTime() {
    return dateTime;
  }

}