/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.core.page;

import java.sql.ResultSet;

import org.joda.time.DateTime;

import br.com.objectos.comuns.relational.jdbc.ResultSetWrapper;
import br.com.objectos.comuns.relational.search.ResultSetLoader;
import br.com.objectos.wiki.core.auth.User;
import br.com.objectos.wiki.core.auth.UserLoader;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class WikiRevisionLoader implements ResultSetLoader<WikiRevision> {

  @Override
  public WikiRevision load(ResultSet resultSet) {
    ResultSetWrapper rs = new ResultSetWrapper("WIKI_REVISION", resultSet);
    return new Loader(rs).build();
  }

  private class Loader implements WikiRevision.Builder {

    private final ResultSetWrapper rs;

    public Loader(ResultSetWrapper rs) {
      this.rs = rs;
    }

    @Override
    public WikiRevision build() {
      WikiRevisionJdbc impl = new WikiRevisionJdbc(this);
      impl.setId(rs.getInt("ID"));
      return impl;
    }
    @Override
    public WikiPage getPage() {
      ResultSet resultSet = rs.getResultSet();
      return new WikiPageLoader().load(resultSet);
    }

    @Override
    public String getContents() {
      return rs.getString("CONTENTS");
    }

    @Override
    public User getUser() {
      ResultSet resultSet = rs.getResultSet();
      return new UserLoader().load(resultSet);
    }

    @Override
    public DateTime getDateTime() {
      return rs.getDateTime("DATE_TIME");
    }

  }

}