/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertTrue;

import java.io.File;
import java.io.IOException;
import java.util.UUID;

import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

import com.google.common.io.Files;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
public class ArgsParserTest {

  private File dir;
  private File file;

  @BeforeClass
  public void prepareFiles() throws IOException {
    dir = Files.createTempDir();
    file = File.createTempFile("args", ".test", dir);
  }

  public void happyWorldEverythingIsFine() throws IOException {
    String[] _args = {
        "-template",
        file.getPath(),
        "-posts",
        dir.getAbsolutePath() };

    try {

      Args args = new ArgsParser(_args).parseAndValidate();

      assertEquals(args.getTemplate(), file);
      assertEquals(args.getPosts(), dir);

    } catch (ArgsException e) {
      System.err.println(e.getMessage());
      assertTrue(false);
    }
  }

  public void templateDoesNotExist() {
    String[] _args = {
        "-template",
        UUID.randomUUID().toString(),
        "-posts",
        dir.getAbsolutePath() };

    try {

      new ArgsParser(_args).parseAndValidate();
      assertTrue(false);

    } catch (ArgsException e) {

      String msg = e.getMessage();
      assertTrue(msg.contains("template"));

    }
  }

  public void postsDoesNotExist() {
    String[] _args = {
        "-template",
        file.getPath(),
        "-posts",
        UUID.randomUUID().toString() };

    try {

      new ArgsParser(_args).parseAndValidate();
      assertTrue(false);

    } catch (ArgsException e) {

      String msg = e.getMessage();
      assertTrue(msg.contains("posts"));

    }
  }

  public void postsIsNotADirectory() {
    String[] _args = {
        "-template",
        file.getPath(),
        "-posts",
        file.getPath() };

    try {

      new ArgsParser(_args).parseAndValidate();
      assertTrue(false);

    } catch (ArgsException e) {

      String msg = e.getMessage();
      assertTrue(msg.contains("directory"));

    }
  }

}