/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import static org.testng.Assert.assertEquals;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.StringReader;

import org.testng.annotations.Guice;
import org.testng.annotations.Test;

import com.google.common.io.CharStreams;
import com.google.inject.Inject;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
@Guice(modules = BlogModule.class)
public class PostIntegrationTest {

  @Inject
  private PostLoader postLoader;
  @Inject
  private PostTemplateLoader templateLoader;

  public void loadingPostFromFileShouldHaveAllPropertiesSet()
      throws IOException {

    File baseDir = new File("src/test/resources/src/main/resources");

    File postFile = new File(baseDir, "posts/001.integration-test.txt");
    File templateFile = new File(baseDir, "templates/post.html");

    Post post = postLoader.load(postFile);
    PostTemplate template = templateLoader.loadFromFile(templateFile);

    String result = post.render(template);

    StringReader reader = CharStreams.newReaderSupplier(result).getInput();
    BufferedReader r = new BufferedReader(reader);

    assertLine(r, "<html>");
    assertLine(r, "<head></head>");
    assertLine(r, "<body>");
    assertLine(r, "<h1>Very original title</h1>");
    assertLine(r, "<span>19/06/2011 18:22</span>");
    assertLine(r, "<span>Marcio Endo</span>");
    assertLine(r, "<div>");
    assertLine(r, "<h1>Heading 1</h1>");
    assertLine(r, "<p> text </p>");
    assertLine(r, "<blockquote>");
    assertLine(r, "<p> I was quoted </p>");
    assertLine(r, "<p> quoted again </p>");
    assertLine(r, "</blockquote>");
    assertLine(r, "</div>");
    assertLine(r, "<script>");
    assertLine(r, "var disqus_identifier = '000001';");
    assertLine(r, "</script>");
    assertLine(r, "</body>");
    assertLine(r, "</html>");

  }

  private void assertLine(BufferedReader reader, String expected)
      throws IOException {

    String linha = reader.readLine();
    assertEquals(linha.trim(), expected);

  }

}