/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertTrue;

import java.io.File;
import java.io.IOException;
import java.util.List;

import org.testng.annotations.Test;

import com.google.common.io.Files;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
public class PostListTest {

  public void postListShouldWorkfineInASingleLevelTree() throws IOException {
    File dir = Files.createTempDir();

    File f0 = File.createTempFile("001-", ".txt", dir);
    File f1 = File.createTempFile("001-", ".txt", dir);
    File.createTempFile("001-", ".tmp", dir);

    List<File> result = new PostList(dir).build();

    assertEquals(result.size(), 2);
    assertTrue(result.contains(f0));
    assertTrue(result.contains(f1));
  }

  public void postListShouldWorkfineInAMultieLevelTree() throws IOException {
    File dir = Files.createTempDir();

    File sub0 = newDir(dir, "sub0");
    File sub1 = newDir(dir, "sub1");
    newDir(dir, "sub2");

    File sub10 = newDir(sub1, "sub0");
    File sub100 = newDir(sub10, "sub0");

    File f0 = newPost(dir);
    File f1 = newPost(sub0);
    File f2 = newPost(sub0);
    File f3 = newPost(sub100);

    List<File> result = new PostList(dir).build();

    assertEquals(result.size(), 4);
    assertTrue(result.contains(f0));
    assertTrue(result.contains(f1));
    assertTrue(result.contains(f2));
    assertTrue(result.contains(f3));
  }

  private File newDir(File dir, String name) {
    File sub = new File(dir, name);
    sub.mkdir();
    return sub;
  }

  private File newPost(File dir) throws IOException {
    return File.createTempFile("001-", ".txt", dir);
  }

}