/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import static org.testng.Assert.assertEquals;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.StringReader;

import org.joda.time.DateTime;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Guice;
import org.testng.annotations.Test;

import com.google.common.io.CharStreams;
import com.google.inject.Inject;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
@Guice(modules = BlogModule.class)
public class PostLoaderTest {

  @Inject
  private PostLoader postLoader;

  private Post thePost;

  @BeforeClass
  public void prepareLoader() throws IOException {
    File baseDir = new File("src/test/resources/src/main/resources");
    File file = new File(baseDir, "posts/002.post-loader.txt");

    thePost = postLoader.load(file);
  }

  public void postIdShouldHaveBeenCorrectlySet() {
    assertEquals(thePost.getId(), "000002");
  }

  public void postPathShouldHaveBeenCorrectlySet() {
    assertEquals(thePost.getPath(), "2011/06/19/very_original_title.html");
  }

  public void postMetaDataShouldHaveBeenSet() throws IOException {
    String author = "Marcio Endo";
    DateTime date = new DateTime("2011-06-19T18:22:24.000-03:00");
    String title = "Very original title";

    assertEquals(thePost.getAuthor(), author);
    assertEquals(thePost.getDate(), date);
    assertEquals(thePost.getTitle(), title);
  }

  public void postContentsShouldHaveBeenSetAndWithSyntaxConverted()
      throws IOException {

    String contents = thePost.getContents();
    StringReader reader = CharStreams.newReaderSupplier(contents).getInput();
    BufferedReader r = new BufferedReader(reader);

    assertLine(r, "<h1>Heading 1</h1>");
    assertLine(r, "<p>");
    assertLine(r, "paragraph0 line0");
    assertLine(r, "paragraph0 line1");
    assertLine(r, "</p>");
    assertLine(r, "<p>");
    assertLine(r, "paragraph1 line0");
    assertLine(r, "</p>");
    assertLine(r, "<h2>Heading 2</h2>");
    assertLine(r, "<p>");
    assertLine(r, "A <strong>bold</strong> text");
    assertLine(r, "A <em>italic</em> text");
    assertLine(r, "</p>");

  }

  private void assertLine(BufferedReader reader, String expected)
      throws IOException {

    String linha = reader.readLine();
    assertEquals(linha.trim(), expected);

  }

}