/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog;

import static org.testng.Assert.assertEquals;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.testng.annotations.Test;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
public class PostTagTest {

  public void selectionTest() {
    Document doc = newDoc("<a></a><h1>{{title}}</h1><b></b>");
    Elements result = PostTag.TITLE.selectFrom(doc);

    assertEquals(result.size(), 1);

    Element r0 = result.get(0);
    assertEquals(r0.toString().trim(), "<h1>{{title}}</h1>");
  }

  public void replacementFullTag() {
    Document doc = newDoc("<h1>{{title}}</h1>");

    Element el = doc.getElementsByTag("h1").first();
    PostTag.TITLE.replace(el, "The title");

    assertEquals(el.toString().trim(), "<h1>The title</h1>");
  }

  public void replacementPartialTag() {
    Document doc = newDoc("<h1>Prefix {{title}}</h1>");

    Element el = doc.getElementsByTag("h1").first();
    PostTag.TITLE.replace(el, "The title");

    assertEquals(el.toString().trim(), "<h1>Prefix The title</h1>");
  }

  public void replacementWithChildren() {
    Document doc = newDoc("<h1>{{title}}<b>b<i>i</i></b></h1>");

    Element el = doc.getElementsByTag("h1").first();
    PostTag.TITLE.replace(el, "The title");

    assertEquals(el.toString().trim(), "<h1>The title<b>b<i>i</i></b></h1>");
  }

  public void replacementWithScriptShouldWork() {
    Document doc = newDoc("<script>'{{post_id}}'</script>");

    Element el = doc.getElementsByTag("script").first();
    PostTag.POST_ID.replace(el, "002");

    assertEquals(el.toString().replaceAll("\\s", ""), "<script>'002'</script>");
  }

  private Document newDoc(String html) {
    return Jsoup.parse(html);
  }

}