/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertTrue;

import org.testng.annotations.Test;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
public class BlockquoteTest {

  public void validStartBlockquote() {
    BlockquoteStart st = start("<blockquote>");

    assertTrue(st.matches());
    assertEquals(st.toString(), "<blockquote>");
  }

  public void validEndBlockquote() {
    BlockquoteEnd end = end("</blockquote>");

    assertTrue(end.matches());
    assertEquals(end.toString(), "</blockquote>");
  }

  public void paragraphsInsideBlockquoteShouldBeMergedToBlockQuote() {
    BlockquoteStart st = start("<blockquote>");
    Paragraph p1 = p("1");
    Paragraph p2 = p("2");
    Paragraph p3 = p("3");
    BlockquoteEnd end = end("</blockquote>");

    assertTrue(st.merge(p1));
    assertTrue(st.merge(p2));
    assertTrue(st.merge(p3));
    assertFalse(st.merge(end));

    String res = st.toString();
    String noSpaces = res.replaceAll("\\s", "");

    assertEquals(noSpaces, "<blockquote><p>123</p></blockquote>");
  }

  public void paragraphsWithBreaksShouldBeProperlyMerged() {
    BlockquoteStart st = start("<blockquote>");
    HtmlElement p1 = p("1");
    HtmlElement p2 = br();
    HtmlElement p3 = p("3");
    BlockquoteEnd end = end("</blockquote>");

    assertTrue(st.merge(p1));
    assertTrue(st.merge(p2));
    assertTrue(st.merge(p3));
    assertFalse(st.merge(end));

    String res = st.toString();
    String noSpaces = res.replaceAll("\\s", "");

    assertEquals(noSpaces, "<blockquote><p>1</p><p>3</p></blockquote>");
  }

  private BlockquoteStart start(String text) {
    return new BlockquoteStart(text);
  }

  private BlockquoteEnd end(String text) {
    return new BlockquoteEnd(text);
  }

  private ParagraphBreak br() {
    return new ParagraphBreak("");
  }

  private Paragraph p(String text) {
    return new Paragraph(text);
  }

}