/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertTrue;

import org.testng.annotations.Test;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
public class HeadingTest {

  public void validH1() {
    Heading h1 = h("---+ Heading");

    assertTrue(h1.matches());
    assertEquals(h1.toString(), "<h1>Heading</h1>");
  }

  public void validH2() {
    Heading h2 = h("---++ Heading");

    assertTrue(h2.matches());
    assertEquals(h2.toString(), "<h2>Heading</h2>");
  }

  public void validH3() {
    Heading h3 = h("------+++ Heading");

    assertTrue(h3.matches());
    assertEquals(h3.toString(), "<h3>Heading</h3>");
  }

  public void invalidH1() {
    Heading h1 = h(" ---+ Heading");

    assertFalse(h1.matches());
  }

  public void validH1WithFormatting() {
    Heading h1 = h("---+ *Heading*");

    assertTrue(h1.matches());
    assertEquals(h1.toString(), "<h1><strong>Heading</strong></h1>");
  }

  private Heading h(String text) {
    return new Heading(text);
  }

}