/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertTrue;

import org.joda.time.DateTime;
import org.joda.time.LocalDate;
import org.testng.annotations.Test;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
public class MetaTest {

  public void validMeta() {
    Meta meta = meta("%META:AUTHOR{Marcio Endo}%");

    assertTrue(meta.matches());
    assertEquals(meta.getKey(), MetaTypes.AUTHOR);
    assertEquals(meta.getValue(), "Marcio Endo");
    assertEquals(meta.toString(), "AUTHOR=Marcio Endo");
  }

  public void validDateConversion() {
    Meta meta = meta("%META:DATE{2011-06-19}%");
    LocalDate localDate = new LocalDate(2011, 6, 19);
    DateTime date = localDate.toDateTimeAtStartOfDay();

    assertTrue(meta.matches());
    assertEquals(meta.getKey(), MetaTypes.DATE);
    assertEquals(meta.getValue(), date);
  }

  public void invalidMeta() {
    Meta meta = meta("META:AUTHOR{Marcio Endo}");

    assertFalse(meta.matches());
  }

  @Test(expectedExceptions = InvalidMetaKeyException.class)
  public void unknownMetaKeyType() {
    meta("%META:UNKNOWN{whatever}%");

    assertFalse(true);
  }

  @Test(expectedExceptions = InvalidMetaValueException.class)
  public void invalidMetaValue() {
    meta("%META:DATE{whatever}%");

    assertFalse(true);
  }

  private Meta meta(String text) {
    return new Meta(text);
  }

}