/*
 * Copyright 2011 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.blog.syntax;

import static org.testng.Assert.assertEquals;

import org.testng.annotations.Test;

/**
 * @author marcio.endo@objectos.com.br (Marcio Endo)
 */
@Test
public class TextDecoratorTest {

  public void paragraphShouldEncloseBoldTags() {
    String result = decorate("*Bold*");

    assertEquals(result, "<strong>Bold</strong>");
  }

  public void paragraphShouldEncloseItalicTags() {
    String result = decorate("_Italic_");

    assertEquals(result, "<em>Italic</em>");
  }

  public void paragraphShouldEncloseBoldItalicTags() {
    String result = decorate("__Bold italic__");

    assertEquals(result, "<strong><em>Bold italic</em></strong>");
  }

  public void paragraphShouldEncloseFixedFontTags() {
    String result = decorate("=Fixed font=");

    assertEquals(result, "<code>Fixed font</code>");
  }

  public void paragraphShouldEncloseBoldFixedTags() {
    String result = decorate("==Bold fixed==");

    assertEquals(result, "<code><b>Bold fixed</b></code>");
  }

  private String decorate(String text) {
    return new TextDecorator(text).decorate();
  }

}