/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki;

import org.joda.time.DateTime;

import br.com.objectos.wiki.core.Web;
import br.com.objectos.wiki.core.WebJdbc;
import br.com.objectos.wiki.core.auth.User;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class FakeWebBuilder implements Web.Builder {

  private String code;
  private String description;
  private User user;
  private DateTime creationTime;
  private DateTime lastUpdate;

  @Override
  public Web build() {
    return new WebJdbc(this);
  }

  public FakeWebBuilder code(String code) {
    this.code = code;
    return this;
  }

  public FakeWebBuilder description(String description) {
    this.description = description;
    return this;
  }

  public FakeWebBuilder user(User user) {
    this.user = user;
    return this;
  }

  public FakeWebBuilder creationTime(DateTime creationTime) {
    this.creationTime = creationTime;
    return this;
  }

  public FakeWebBuilder lastUpdate(DateTime lastUpdate) {
    this.lastUpdate = lastUpdate;
    return this;
  }

  @Override
  public String getCode() {
    return code;
  }

  @Override
  public String getDescription() {
    return description;
  }

  @Override
  public User getUser() {
    return user;
  }

  @Override
  public DateTime getCreationTime() {
    return creationTime;
  }

  @Override
  public DateTime getLastUpdate() {
    return lastUpdate;
  }

}