/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki;

import java.util.List;

import org.joda.time.DateTime;

import br.com.objectos.comuns.testing.jdbc.EntitySet;
import br.com.objectos.comuns.testing.jdbc.SqlUnit;
import br.com.objectos.comuns.testing.jdbc.Truncate;
import br.com.objectos.wiki.auth.FakeUsers;
import br.com.objectos.wiki.core.Web;

import com.google.common.collect.ImmutableList;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class FakeWebs implements EntitySet {

  public static Web WEB_1 = newInstance()
      .code("1")
      .description("Descrição teste")
      .user(FakeUsers.USER_1)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();
  public static Web WEB_2 = newInstance()
      .code("2")
      .description("Descrição teste 2")
      .user(FakeUsers.USER_2)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();
  public static Web WEB_3 = newInstance()
      .code("3")
      .description("Descrição teste 3")
      .user(FakeUsers.USER_3)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();

  private static final List<Web> all = ImmutableList.<Web> builder()
      .add(WEB_1)
      .add(WEB_2)
      .add(WEB_3)
      .build();

  public static List<Web> getAll() {
    return all;
  }

  @Override
  public void truncate(Truncate truncate) {
    truncate.table("OBJ_WIKI.WEB");
  }

  @Override
  public void load(SqlUnit sqlUnit) {
    sqlUnit.batchInsert(all);
  }

  private static FakeWebBuilder newInstance() {
    return new FakeWebBuilder();
  }

}
