/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.attach;

import java.util.UUID;

import org.joda.time.DateTime;

import br.com.objectos.wiki.core.attach.Attachment;
import br.com.objectos.wiki.core.attach.AttachmentJdbc;
import br.com.objectos.wiki.core.auth.User;
import br.com.objectos.wiki.core.page.WikiPage;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class FakeAttachmentBuilder implements Attachment.Builder {

  private UUID uuid;
  private String mime;
  private String name;
  private String description;
  private long size;
  private User user;
  private DateTime creationTime;
  private DateTime lastUpdate;
  private WikiPage page;

  @Override
  public Attachment build() {
    return new AttachmentJdbc(this);
  }

  public FakeAttachmentBuilder uuid(UUID uuid) {
    this.uuid = uuid;
    return this;
  }

  public FakeAttachmentBuilder mime(String mime) {
    this.mime = mime;
    return this;
  }

  public FakeAttachmentBuilder name(String name) {
    this.name = name;
    return this;
  }

  public FakeAttachmentBuilder description(String description) {
    this.description = description;
    return this;
  }

  public FakeAttachmentBuilder size(long size) {
    this.size = size;
    return this;
  }

  public FakeAttachmentBuilder user(User user) {
    this.user = user;
    return this;
  }

  public FakeAttachmentBuilder creationTime(DateTime creationTime) {
    this.creationTime = creationTime;
    return this;
  }

  public FakeAttachmentBuilder lastUpdate(DateTime lastUpdate) {
    this.lastUpdate = lastUpdate;
    return this;
  }

  public FakeAttachmentBuilder page(WikiPage page) {
    this.page = page;
    return this;
  }

  @Override
  public UUID getUuid() {
    return uuid;
  }

  @Override
  public WikiPage getPage() {
    return page;
  }

  @Override
  public String getMime() {
    return mime;
  }

  @Override
  public String getName() {
    return name;
  }

  @Override
  public String getDescription() {
    return description;
  }

  @Override
  public long getSize() {
    return size;
  }

  @Override
  public User getUser() {
    return user;
  }

  @Override
  public DateTime getCreationTime() {
    return creationTime;
  }

  @Override
  public DateTime getLastUpdate() {
    return lastUpdate;
  }

}