/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.attach;

import java.util.List;
import java.util.UUID;

import org.joda.time.DateTime;

import br.com.objectos.comuns.testing.jdbc.EntitySet;
import br.com.objectos.comuns.testing.jdbc.SqlUnit;
import br.com.objectos.comuns.testing.jdbc.Truncate;
import br.com.objectos.wiki.auth.FakeUsers;
import br.com.objectos.wiki.core.attach.Attachment;
import br.com.objectos.wiki.core.page.WikiPage;
import br.com.objectos.wiki.core.page.WikiPageKey;
import br.com.objectos.wiki.page.FakeWikiPages;

import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ListMultimap;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class FakeAttachments implements EntitySet {

  public static Attachment PAGE_A_ATTACHMENT_1 = newInstance()
      .uuid(UUID.randomUUID())
      .page(FakeWikiPages.WEB_1_PAGEA)
      .mime("test mine")
      .name("attachment name")
      .description("attachment description")
      .size(50L)
      .user(FakeUsers.USER_1)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();
  public static Attachment PAGE_A_ATTACHMENT_2 = newInstance()
      .uuid(UUID.randomUUID())
      .page(FakeWikiPages.WEB_1_PAGEA)
      .mime("test mine 2")
      .name("attachment name 2")
      .description("attachment description 3")
      .size(70L)
      .user(FakeUsers.USER_2)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();
  public static Attachment PAGE_A_ATTACHMENT_3 = newInstance()
      .uuid(UUID.randomUUID())
      .page(FakeWikiPages.WEB_1_PAGEA)
      .mime("test mine 3")
      .name("attachment name 3")
      .description("attachment description 3")
      .size(80L)
      .user(FakeUsers.USER_3)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();

  public static Attachment PAGE_B_ATTACHMENT_4 = newInstance()
      .uuid(UUID.randomUUID())
      .page(FakeWikiPages.WEB_1_PAGEC)
      .mime("test mine")
      .name("attachment name")
      .description("attachment description")
      .size(50L)
      .user(FakeUsers.USER_1)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();
  public static Attachment PAGE_B_ATTACHMENT_5 = newInstance()
      .uuid(UUID.randomUUID())
      .page(FakeWikiPages.WEB_1_PAGEC)
      .mime("test mine 2")
      .name("attachment name 2")
      .description("attachment description 3")
      .size(70L)
      .user(FakeUsers.USER_2)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();
  public static Attachment PAGE_B_ATTACHMENT_6 = newInstance()
      .uuid(UUID.randomUUID())
      .page(FakeWikiPages.WEB_1_PAGEC)
      .mime("test mine 3")
      .name("attachment name 3")
      .description("attachment description 3")
      .size(80L)
      .user(FakeUsers.USER_3)
      .creationTime(new DateTime())
      .lastUpdate(new DateTime())
      .build();

  private static final List<Attachment> all = ImmutableList.<Attachment> builder()
      .add(PAGE_A_ATTACHMENT_1)
      .add(PAGE_A_ATTACHMENT_2)
      .add(PAGE_A_ATTACHMENT_3)

      .add(PAGE_B_ATTACHMENT_4)
      .add(PAGE_B_ATTACHMENT_5)
      .add(PAGE_B_ATTACHMENT_6)
      .build();

  private static final ListMultimap<WikiPageKey, Attachment> pageKeyMap = ArrayListMultimap
      .create();

  public static List<Attachment> byPageKey(WikiPageKey pageKey) {
    return pageKeyMap.get(pageKey);
  }

  public static final List<Attachment> getAll() {
    return all;
  }

  @Override
  public void truncate(Truncate truncate) {
    truncate.table("OBJ_WIKI.ATTACHMENT");
  }

  @Override
  public void load(SqlUnit sqlUnit) {
    sqlUnit.batchInsert(all);
    maps();
  }

  private void maps() {
    pageKeyMap.clear();

    for (Attachment attachment : all) {
      WikiPage page = attachment.getPage();
      WikiPageKey pageKey = page.getKey();

      pageKeyMap.put(pageKey, attachment);
    }
  }

  public static FakeAttachmentBuilder newInstance() {
    return new FakeAttachmentBuilder();
  }

}