/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.auth;

import org.joda.time.DateTime;

import br.com.objectos.wiki.core.auth.User;
import br.com.objectos.wiki.core.auth.UserJdbc;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class FakeUserBuilder implements User.Builder {

  private String login;
  private String password;
  private DateTime creationTime;
  private DateTime lastUpdate;

  @Override
  public User build() {
    return new UserJdbc(this);
  }

  public FakeUserBuilder login(String login) {
    this.login = login;
    return this;
  }

  public FakeUserBuilder password(String password) {
    this.password = password;
    return this;
  }

  public FakeUserBuilder creationTime(DateTime creationTime) {
    this.creationTime = creationTime;
    return this;
  }

  public FakeUserBuilder lastUpdate(DateTime lastUpdate) {
    this.lastUpdate = lastUpdate;
    return this;
  }

  @Override
  public String getLogin() {
    return login;
  }

  @Override
  public String getPassword() {
    return password;
  }

  @Override
  public DateTime getCreationTime() {
    return creationTime;
  }

  @Override
  public DateTime getLastUpdate() {
    return lastUpdate;
  }

}