/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.mail;

import static com.google.common.collect.Lists.transform;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;

import java.util.List;

import org.testng.annotations.BeforeClass;
import org.testng.annotations.Guice;
import org.testng.annotations.Test;

import br.com.objectos.comuns.testing.jdbc.SqlUnit;
import br.com.objectos.wiki.auth.FakeUsers;
import br.com.objectos.wiki.core.WikiTestModule;
import br.com.objectos.wiki.core.auth.User;
import br.com.objectos.wiki.core.auth.UserKey;
import br.com.objectos.wiki.core.mail.Email;
import br.com.objectos.wiki.core.mail.EmailCache;

import com.google.inject.Inject;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
@Test
@Guice(modules = { WikiTestModule.class })
public class EmailCacheTest {

  @Inject
  private EmailCache cache;

  @Inject
  private SqlUnit sqlUnit;

  @BeforeClass
  public void prepararSqlUnit() {
    sqlUnit.loadEntitySet(FakeUsers.class);
    sqlUnit.loadEntitySet(FakeEmails.class);
  }

  public void by_user() {
    User user = FakeUsers.USER_1;
    UserKey userKey = user.getKey();

    List<Email> counter = FakeEmails.byUserKey(userKey);
    List<String> proof = transform(counter, new EmailToString());

    List<Email> list = cache.byUserKey(userKey);
    List<String> res = transform(list, new EmailToString());

    assertThat(res.size(), equalTo(3));
    assertThat(res, equalTo(proof));
  }

}