/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.mail;

import java.util.List;

import br.com.objectos.comuns.testing.jdbc.EntitySet;
import br.com.objectos.comuns.testing.jdbc.SqlUnit;
import br.com.objectos.comuns.testing.jdbc.Truncate;
import br.com.objectos.wiki.auth.FakeUsers;
import br.com.objectos.wiki.core.auth.User;
import br.com.objectos.wiki.core.auth.UserKey;
import br.com.objectos.wiki.core.mail.Email;

import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ListMultimap;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class FakeEmails implements EntitySet {

  public static Email EMAIL_1_A = newInstance()
      .user(FakeUsers.USER_1)
      .emailAddress("email@email.com")
      .build();
  public static Email EMAIL_1_B = newInstance()
      .user(FakeUsers.USER_1)
      .emailAddress("email@email.com")
      .build();
  public static Email EMAIL_1_C = newInstance()
      .user(FakeUsers.USER_1)
      .emailAddress("email@email.com")
      .build();

  public static Email EMAIL_3_A = newInstance()
      .user(FakeUsers.USER_3)
      .emailAddress("email@email.com")
      .build();
  public static Email EMAIL_3_B = newInstance()
      .user(FakeUsers.USER_3)
      .emailAddress("email@email.com")
      .build();
  public static Email EMAIL_3_C = newInstance()
      .user(FakeUsers.USER_3)
      .emailAddress("email@email.com")
      .build();

  private static List<Email> all = ImmutableList.<Email> builder()
      .add(EMAIL_1_A)
      .add(EMAIL_1_B)
      .add(EMAIL_1_C)

      .add(EMAIL_3_A)
      .add(EMAIL_3_B)
      .add(EMAIL_3_C)
      .build();

  private static final ListMultimap<UserKey, Email> userKeyMap = ArrayListMultimap.create();

  public static List<Email> byUserKey(UserKey userKey) {
    return userKeyMap.get(userKey);
  }

  FakeEmails() {
  }

  @Override
  public void truncate(Truncate truncate) {
    truncate.table("OBJ_WIKI.EMAIL");
  }

  @Override
  public void load(SqlUnit sqlUnit) {
    sqlUnit.batchInsert(all);
    maps();
  }

  private void maps() {
    userKeyMap.clear();

    for (Email email : all) {
      User user = email.getUser();
      UserKey userKey = user.getKey();

      userKeyMap.put(userKey, email);
    }
  }

  private static FakeEmailBuider newInstance() {
    return new FakeEmailBuider();
  }

}