/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.page;

import java.util.List;

import br.com.objectos.comuns.testing.jdbc.EntitySet;
import br.com.objectos.comuns.testing.jdbc.SqlUnit;
import br.com.objectos.comuns.testing.jdbc.Truncate;
import br.com.objectos.wiki.FakeWebs;
import br.com.objectos.wiki.core.Web;
import br.com.objectos.wiki.core.WebKey;
import br.com.objectos.wiki.core.page.WikiPage;

import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ListMultimap;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class FakeWikiPages implements EntitySet {

  public static WikiPage WEB_1_PAGEA = newInstance()
      .web(FakeWebs.WEB_1)
      .wikiWord("Wiki Page A")
      .build();
  public static WikiPage WEB_1_PAGEB = newInstance()
      .web(FakeWebs.WEB_1)
      .wikiWord("Wiki Page B")
      .build();
  public static WikiPage WEB_1_PAGEC = newInstance()
      .web(FakeWebs.WEB_1)
      .wikiWord("Wiki Page C")
      .build();

  public static WikiPage WEB_3_PAGEA = newInstance()
      .web(FakeWebs.WEB_3)
      .wikiWord("Wiki Page A")
      .build();
  public static WikiPage WEB_3_PAGEB = newInstance()
      .web(FakeWebs.WEB_3)
      .wikiWord("Wiki Page B")
      .build();
  public static WikiPage WEB_3_PAGEC = newInstance()
      .web(FakeWebs.WEB_3)
      .wikiWord("Wiki Page C")
      .build();

  private static final List<WikiPage> all = ImmutableList.<WikiPage> builder()
      .add(WEB_1_PAGEA)
      .add(WEB_1_PAGEB)
      .add(WEB_1_PAGEC)

      .add(WEB_3_PAGEA)
      .add(WEB_3_PAGEB)
      .add(WEB_3_PAGEC)
      .build();

  private static final ListMultimap<WebKey, WikiPage> webKeyMap = ArrayListMultimap.create();

  public static List<WikiPage> byWebKey(WebKey webKey) {
    return webKeyMap.get(webKey);
  }

  FakeWikiPages() {
  }

  @Override
  public void truncate(Truncate truncate) {
    truncate.table("OBJ_WIKI.WIKI_PAGE");
  }

  @Override
  public void load(SqlUnit sqlUnit) {
    sqlUnit.batchInsert(all);
    maps();
  }

  private void maps() {
    webKeyMap.clear();

    for (WikiPage page : all) {
      Web web = page.getWeb();
      WebKey webKey = web.getKey();

      webKeyMap.put(webKey, page);
    }
  }

  public static FakeWikiPageBuilder newInstance() {
    return new FakeWikiPageBuilder();
  }

}