/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.page;

import java.util.List;

import org.joda.time.DateTime;

import br.com.objectos.comuns.testing.jdbc.EntitySet;
import br.com.objectos.comuns.testing.jdbc.SqlUnit;
import br.com.objectos.comuns.testing.jdbc.Truncate;
import br.com.objectos.wiki.auth.FakeUsers;
import br.com.objectos.wiki.core.page.WikiPage;
import br.com.objectos.wiki.core.page.WikiPageKey;
import br.com.objectos.wiki.core.page.WikiRevision;

import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ListMultimap;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
public class FakeWikiRevisions implements EntitySet {

  public static WikiRevision WIKI_REVISION_1_A = newInstance()
      .page(FakeWikiPages.WEB_1_PAGEA)
      .contents("test contents 1")
      .user(FakeUsers.USER_1)
      .dateTime(new DateTime())
      .build();

  public static WikiRevision WIKI_REVISION_1_B = newInstance()
      .page(FakeWikiPages.WEB_1_PAGEA)
      .contents("test contents 2")
      .user(FakeUsers.USER_2)
      .dateTime(new DateTime())
      .build();

  public static WikiRevision WIKI_REVISION_1_C = newInstance()
      .page(FakeWikiPages.WEB_1_PAGEA)
      .contents("test contents 3")
      .user(FakeUsers.USER_1)
      .dateTime(new DateTime())
      .build();

  public static WikiRevision WIKI_REVISION_2_A = newInstance()
      .page(FakeWikiPages.WEB_1_PAGEB)
      .contents("test contents 1")
      .user(FakeUsers.USER_1)
      .dateTime(new DateTime())
      .build();

  public static WikiRevision WIKI_REVISION_2_B = newInstance()
      .page(FakeWikiPages.WEB_1_PAGEB)
      .contents("test contents 2")
      .user(FakeUsers.USER_2)
      .dateTime(new DateTime())
      .build();

  public static WikiRevision WIKI_REVISION_2_C = newInstance()
      .page(FakeWikiPages.WEB_1_PAGEB)
      .contents("test contents 3")
      .user(FakeUsers.USER_1)
      .dateTime(new DateTime())
      .build();

  private static List<WikiRevision> all = ImmutableList.<WikiRevision> builder()
      .add(WIKI_REVISION_1_A)
      .add(WIKI_REVISION_1_B)
      .add(WIKI_REVISION_1_C)

      .add(WIKI_REVISION_2_A)
      .add(WIKI_REVISION_2_B)
      .add(WIKI_REVISION_2_C)
      .build();

  private static final ListMultimap<WikiPageKey, WikiRevision> pageKeyMap = ArrayListMultimap
      .create();

  public static List<WikiRevision> byPageKey(WikiPageKey pageKey) {
    return pageKeyMap.get(pageKey);
  }

  public static final List<WikiRevision> getAll() {
    return all;
  }

  @Override
  public void truncate(Truncate truncate) {
    truncate.table("OBJ_WIKI.WIKI_REVISION");
  }

  @Override
  public void load(SqlUnit sqlUnit) {
    sqlUnit.batchInsert(all);
    maps();
  }

  private void maps() {
    pageKeyMap.clear();

    for (WikiRevision wikiRevision : all) {
      WikiPage page = wikiRevision.getPage();
      WikiPageKey pageKey = page.getKey();

      pageKeyMap.put(pageKey, wikiRevision);
    }
  }

  public static FakeWikiRevisionBulder newInstance() {
    return new FakeWikiRevisionBulder();
  }

}