/*
 * Copyright 2013 Objectos, Fábrica de Software LTDA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package br.com.objectos.wiki.page;

import static com.google.common.collect.Lists.transform;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;

import java.util.List;

import org.testng.annotations.BeforeClass;
import org.testng.annotations.Guice;
import org.testng.annotations.Test;

import br.com.objectos.comuns.testing.jdbc.SqlUnit;
import br.com.objectos.wiki.FakeWebs;
import br.com.objectos.wiki.auth.FakeUsers;
import br.com.objectos.wiki.core.Web;
import br.com.objectos.wiki.core.WebKey;
import br.com.objectos.wiki.core.WikiTestModule;
import br.com.objectos.wiki.core.page.FindWikiPage;
import br.com.objectos.wiki.core.page.WikiPage;
import br.com.objectos.wiki.core.page.WikiPageKey;

import com.google.inject.Inject;

/**
 * @author edenir.anschau@objectos.com.br (Edenir Norberto Anschau)
 */
@Test
@Guice(modules = { WikiTestModule.class })
public class FindWikiPageTest {

  @Inject
  private FindWikiPage findWikiPage;

  @Inject
  private SqlUnit sqlUnit;

  @BeforeClass
  public void prepararSqlUnit() {
    sqlUnit.loadEntitySet(FakeUsers.class);
    sqlUnit.loadEntitySet(FakeWebs.class);
    sqlUnit.loadEntitySet(FakeWikiPages.class);
  }

  public void by_wikipage_key() {
    WikiPage page = FakeWikiPages.WEB_1_PAGEA;
    String prova = new WikiPageToString().apply(page);

    WikiPageKey pageKey = new WikiPageKey(page);
    WikiPage pojo = findWikiPage.byWikiPageKey(pageKey);
    String res = new WikiPageToString().apply(pojo);

    assertThat(res, equalTo(prova));
  }

  public void by_web_key() {
    Web web = FakeWebs.WEB_1;
    WebKey webKey = web.getKey();

    List<WikiPage> contra = FakeWikiPages.byWebKey(webKey);
    List<String> prova = transform(contra, new WikiPageToString());

    List<WikiPage> list = findWikiPage.byWebKey(webKey);
    List<String> res = transform(list, new WikiPageToString());

    assertThat(res.size(), equalTo(3));
    assertThat(res, equalTo(prova));
  }

}